<?php
/**
 * Project section
 *
 * This is the template for the content of project section
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */
if ( ! function_exists( 'korpo_add_project_section' ) ) :
    /**
    * Add project section
    *
    *@since Korpo 1.0.0
    */
    function korpo_add_project_section() {
    	$options = korpo_get_theme_options();
        // Check if project is enabled on frontpage
        $project_enable = apply_filters( 'korpo_section_status', true, 'project_section_enable' );

        if ( true !== $project_enable ) {
            return false;
        }
        // Get project section details
        $section_details = array();
        $section_details = apply_filters( 'korpo_filter_project_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render project section now.
        korpo_render_project_section( $section_details );
    }
endif;

if ( ! function_exists( 'korpo_get_project_section_details' ) ) :
    /**
    * project section details.
    *
    * @since Korpo 1.0.0
    * @param array $input project section details.
    */
    function korpo_get_project_section_details( $input ) {
        $options = korpo_get_theme_options();

        // Content type.
        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= 4; $i++ ) {
            if ( ! empty( $options['project_content_page_' . $i] ) )
                $page_ids[] = $options['project_content_page_' . $i];
        }
        
        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => 4,
            'orderby'           => 'post__in',
            );                    


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = get_the_content();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// project section content details.
add_filter( 'korpo_filter_project_section_details', 'korpo_get_project_section_details' );


if ( ! function_exists( 'korpo_render_project_section' ) ) :
  /**
   * Start project section
   *
   * @return string project content
   * @since Korpo 1.0.0
   *
   */
   function korpo_render_project_section( $content_details = array() ) {
        $options = korpo_get_theme_options();
        $title = ! empty( $options['project_title'] ) ? $options['project_title'] : '';
        $background = ! empty( $options['project_image'] ) ? $options['project_image'] : '';
        $i = 1;
        $count = count( $content_details );

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="our-projects">
            <div class="projects-section-wrapper <?php echo ! empty( $background ) ? 'has' : 'no'; ?>-featured-image">
                <div class="featured-image" 
                <?php if ( ! empty( $background ) ) : ?>
                    style="background-image: url('<?php echo esc_url( $background ); ?>');"
                <?php endif; ?>
                >
                    <div class="overlay"></div>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <?php if ( ! empty( $title ) ) : ?>
                        <div class="section-header">
                            <span class="section-subtitle"><?php echo esc_html( $title ); ?></span>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="project-slider" data-slick='{"slidesToShow": 2, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "fade": false }'>
                        <div class="slick-item">
                            <?php foreach ( $content_details as $content ) : ?>
                                <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                                    <div class="project-content-wrapper" 
                                    <?php if ( ! empty( $content['image'] ) ) : ?>
                                        style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"
                                    <?php endif; ?>
                                    >
                                        <div class="project-deatils">
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>

                                        </div><!-- .project-details --> 
                                    </div><!-- .project-content-wrapper -->
                                </article>
                                <?php if ( $count > $i && $i%2 == 0 ) : ?>  
                                    </div><!-- .slick-item -->
                                    <div class="slick-item">
                                <?php endif; 
                                $i++;
                            endforeach; ?>
                        </div><!-- .slick-item -->
                    </div><!-- .section-content -->
                </div><!-- .entry-container -->
            </div>
        </section><!-- #our-projects -->
    <?php }
endif;